package de.fhw.komponentenarchitekturen.knauf.stateless;
import javax.ejb.Remote;

/**
 * Remote Interface of the GeometricModelBean.
 * 
 */
@Remote
public interface GeometricModelRemote {

  /**
   * Compute the volume of a square stone
   * 
   * @param a Length of side a, &gt; 0
   * @param b Length of side b, &gt; 0
   * @param c Length of side c, &gt; 0
   * @return Volume of the square stone = a * b * c
   * @exception InvalidParameterException If a or b or c &lt;= 0.
   */
  public double computeCuboidVolume(double a, double b, double c) throws InvalidParameterException;

  /**
   * Compute the surface of a square stone
   * 
   * @param a Length of side a, &gt; 0
   * @param b Length of side b, &gt; 0
   * @param c Length of side c, &gt; 0
   * @return Surface of the square stone = 2 * (a * b) + 2 * (b*c) + 2 * (a * c)
   * @exception InvalidParameterException If a or b or c &lt;= 0.
   */
  public double computeCuboidSurface(double a, double b, double c) throws InvalidParameterException;

}
